@@ -27,12 +27,10 @@
  * The user can activate tracers by setting the environment variable GST_TRACE
  * to a ';' separated list of tracers.
  *
- * Note that instanciating tracers at runtime is possible but is not thread safe
+ * Note that instantiating tracers at runtime is possible but is not thread safe
  * and needs to be done before any pipeline state is set to PAUSED.
  */
 
-#define GST_USE_UNSTABLE_API
-
 #include "gst_private.h"
 #include "gsttracer.h"
 #include "gsttracerfactory.h"
@@ -55,7 +53,10 @@ static const gchar *_quark_strings[] = {
   "pad-link-pre", "pad-link-post", "pad-unlink-pre", "pad-unlink-post",
   "element-change-state-pre", "element-change-state-post",
   "mini-object-created", "mini-object-destroyed", "object-created",
-  "object-destroyed",
+  "object-destroyed", "mini-object-reffed", "mini-object-unreffed",
+  "object-reffed", "object-unreffed", "plugin-feature-loaded",
+  "pad-chain-pre", "pad-chain-post", "pad-chain-list-pre",
+  "pad-chain-list-post",
 };
 
 GQuark _priv_gst_tracer_quark_table[GST_TRACER_QUARK_MAX];
@@ -113,12 +114,18 @@ _priv_gst_tracing_init (void)
       if ((feature = gst_registry_lookup_feature (registry, t[i]))) {
         factory = GST_TRACER_FACTORY (gst_plugin_feature_load (feature));
         if (factory) {
+          GstTracer *tracer;
+
           GST_INFO_OBJECT (factory, "creating tracer: type-id=%u",
               (guint) factory->type);
 
+          tracer = g_object_new (factory->type, "params", params, NULL);
+
+          /* Clear floating flag */
+          gst_object_ref_sink (tracer);
+
           /* tracers register them self to the hooks */
-          gst_object_unref (g_object_new (factory->type, "params", params,
-                  NULL));
+          gst_object_unref (tracer);
         } else {
           GST_WARNING_OBJECT (feature,
               "loading plugin containing feature %s failed!", t[i]);
@@ -181,6 +188,8 @@ gst_tracing_register_hook_id (GstTracer * tracer, GQuark detail, GCallback func)
  *
  * Register @func to be called when the trace hook @detail is getting invoked.
  * Use %NULL for @detail to register to all hooks.
+ *
+ * Since: 1.8
  */
 void
 gst_tracing_register_hook (GstTracer * tracer, const gchar * detail,
@@ -189,4 +198,55 @@ gst_tracing_register_hook (GstTracer * tracer, const gchar * detail,
   gst_tracing_register_hook_id (tracer, g_quark_try_string (detail), func);
 }
 
+/**
+ * gst_tracing_get_active_tracers:
+ *
+ * Get a list of all active tracer objects owned by the tracing framework for
+ * the entirety of the run-time of the process or till gst_deinit() is called.
+ *
+ * Returns: (transfer full) (element-type Gst.Tracer): A #GList of
+ * #GstTracer objects
+ *
+ * Since: 1.18
+ */
+GList *
+gst_tracing_get_active_tracers (void)
+{
+  GList *tracers, *h_list, *h_node, *t_node;
+  GstTracerHook *hook;
+
+  if (!_priv_tracer_enabled || !_priv_tracers)
+    return NULL;
+
+  tracers = NULL;
+  h_list = g_hash_table_get_values (_priv_tracers);
+  for (h_node = h_list; h_node; h_node = g_list_next (h_node)) {
+    for (t_node = h_node->data; t_node; t_node = g_list_next (t_node)) {
+      hook = (GstTracerHook *) t_node->data;
+      /* Skip duplicate tracers from different hooks. This function is O(n), but
+       * that should be fine since the number of tracers enabled on a process
+       * should be small. */
+      if (g_list_index (tracers, hook->tracer) >= 0)
+        continue;
+      tracers = g_list_prepend (tracers, gst_object_ref (hook->tracer));
+    }
+  }
+  g_list_free (h_list);
+
+  return tracers;
+}
+
+#else /* !GST_DISABLE_GST_TRACER_HOOKS */
+
+void
+gst_tracing_register_hook (GstTracer * tracer, const gchar * detail,
+    GCallback func)
+{
+}
+
+GList *
+gst_tracing_get_active_tracers (void)
+{
+  return NULL;
+}
 #endif /* GST_DISABLE_GST_TRACER_HOOKS */
