@@ -106,8 +106,8 @@
  * since then can be queried with gst_adapter_distance_from_discont().
  *
  * A last thing to note is that while #GstAdapter is pretty optimized,
- * merging buffers still might be an operation that requires a malloc() and
- * memcpy() operation, and these operations are not the fastest. Because of
+ * merging buffers still might be an operation that requires a `malloc()` and
+ * `memcpy()` operation, and these operations are not the fastest. Because of
  * this, some functions like gst_adapter_available_fast() are provided to help
  * speed up such cases should you want to. To avoid repeated memory allocations,
  * gst_adapter_copy() can be used to copy data into a (statically allocated)
@@ -919,7 +919,8 @@ foreach_metadata (GstBuffer * inbuf, GstMeta ** meta, gpointer user_data)
   const GstMetaInfo *info = (*meta)->info;
   gboolean do_copy = FALSE;
 
-  if (gst_meta_api_type_has_tag (info->api, _gst_meta_tag_memory)) {
+  if (gst_meta_api_type_has_tag (info->api, _gst_meta_tag_memory)
+      || gst_meta_api_type_has_tag (info->api, _gst_meta_tag_memory_reference)) {
     /* never call the transform_meta with memory specific metadata */
     GST_DEBUG ("not copying memory specific metadata %s",
         g_type_name (info->api));
@@ -1365,7 +1366,7 @@ gst_adapter_available_fast (GstAdapter * adapter)
 }
 
 /**
- * gst_adapter_get_distance_from_discont:
+ * gst_adapter_distance_from_discont:
  * @adapter: a #GstAdapter
  *
  * Get the distance in bytes since the last buffer with the
